@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -246,7 +246,6 @@ class FleetRoutingAsyncClient:
         ``Vehicle``\ s that minimizes the total cost where cost has many
         components defined in the ``ShipmentModel``.
 
-
         .. code-block:: python
 
             from google.cloud import optimization_v1
@@ -313,7 +312,12 @@ class FleetRoutingAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -338,7 +342,6 @@ class FleetRoutingAsyncClient:
         containing ``ShipmentRoute``\ s, which are a set of routes to be
         performed by vehicles minimizing the overall cost.
 
-
         .. code-block:: python
 
             from google.cloud import optimization_v1
@@ -417,7 +420,12 @@ class FleetRoutingAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
