@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib
@@ -55,7 +55,10 @@ class FleetRoutingClientMeta(type):
     _transport_registry["grpc"] = FleetRoutingGrpcTransport
     _transport_registry["grpc_asyncio"] = FleetRoutingGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[FleetRoutingTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[FleetRoutingTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -183,7 +186,9 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         return self._transport
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -196,9 +201,13 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -207,9 +216,13 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -218,9 +231,13 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -229,10 +246,14 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -431,7 +452,6 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         ``Vehicle``\ s that minimizes the total cost where cost has many
         components defined in the ``ShipmentModel``.
 
-
         .. code-block:: python
 
             from google.cloud import optimization_v1
@@ -490,7 +510,12 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -515,7 +540,6 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         containing ``ShipmentRoute``\ s, which are a set of routes to be
         performed by vehicles minimizing the overall cost.
 
-
         .. code-block:: python
 
             from google.cloud import optimization_v1
@@ -586,7 +610,12 @@ class FleetRoutingClient(metaclass=FleetRoutingClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
