@@ -91,7 +91,10 @@ def test__get_default_mtls_endpoint():
 
 @pytest.mark.parametrize(
     "client_class,transport_name",
-    [(FleetRoutingClient, "grpc"), (FleetRoutingAsyncClient, "grpc_asyncio"),],
+    [
+        (FleetRoutingClient, "grpc"),
+        (FleetRoutingAsyncClient, "grpc_asyncio"),
+    ],
 )
 def test_fleet_routing_client_from_service_account_info(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
@@ -134,7 +137,10 @@ def test_fleet_routing_client_service_account_always_use_jwt(
 
 @pytest.mark.parametrize(
     "client_class,transport_name",
-    [(FleetRoutingClient, "grpc"), (FleetRoutingAsyncClient, "grpc_asyncio"),],
+    [
+        (FleetRoutingClient, "grpc"),
+        (FleetRoutingAsyncClient, "grpc_asyncio"),
+    ],
 )
 def test_fleet_routing_client_from_service_account_file(client_class, transport_name):
     creds = ga_credentials.AnonymousCredentials()
@@ -494,7 +500,9 @@ def test_fleet_routing_client_client_options_scopes(
     client_class, transport_class, transport_name
 ):
     # Check the case scopes are provided.
-    options = client_options.ClientOptions(scopes=["1", "2"],)
+    options = client_options.ClientOptions(
+        scopes=["1", "2"],
+    )
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options, transport=transport_name)
@@ -632,10 +640,17 @@ def test_fleet_routing_client_create_channel_credentials_file(
         )
 
 
-@pytest.mark.parametrize("request_type", [fleet_routing.OptimizeToursRequest, dict,])
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        fleet_routing.OptimizeToursRequest,
+        dict,
+    ],
+)
 def test_optimize_tours(request_type, transport: str = "grpc"):
     client = FleetRoutingClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -646,7 +661,8 @@ def test_optimize_tours(request_type, transport: str = "grpc"):
     with mock.patch.object(type(client.transport.optimize_tours), "__call__") as call:
         # Designate an appropriate return value for the call.
         call.return_value = fleet_routing.OptimizeToursResponse(
-            request_label="request_label_value", total_cost=0.10840000000000001,
+            request_label="request_label_value",
+            total_cost=0.10840000000000001,
         )
         response = client.optimize_tours(request)
 
@@ -665,7 +681,8 @@ def test_optimize_tours_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = FleetRoutingClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -681,7 +698,8 @@ async def test_optimize_tours_async(
     transport: str = "grpc_asyncio", request_type=fleet_routing.OptimizeToursRequest
 ):
     client = FleetRoutingAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -693,7 +711,8 @@ async def test_optimize_tours_async(
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
             fleet_routing.OptimizeToursResponse(
-                request_label="request_label_value", total_cost=0.10840000000000001,
+                request_label="request_label_value",
+                total_cost=0.10840000000000001,
             )
         )
         response = await client.optimize_tours(request)
@@ -715,7 +734,9 @@ async def test_optimize_tours_async_from_dict():
 
 
 def test_optimize_tours_field_headers():
-    client = FleetRoutingClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -735,12 +756,17 @@ def test_optimize_tours_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_optimize_tours_field_headers_async():
-    client = FleetRoutingAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = FleetRoutingAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -762,15 +788,23 @@ async def test_optimize_tours_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.parametrize(
-    "request_type", [fleet_routing.BatchOptimizeToursRequest, dict,]
+    "request_type",
+    [
+        fleet_routing.BatchOptimizeToursRequest,
+        dict,
+    ],
 )
 def test_batch_optimize_tours(request_type, transport: str = "grpc"):
     client = FleetRoutingClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -798,7 +832,8 @@ def test_batch_optimize_tours_empty_call():
     # This test is a coverage failsafe to make sure that totally empty calls,
     # i.e. request == None and no flattened fields passed, work.
     client = FleetRoutingClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
 
     # Mock the actual call within the gRPC stub, and fake the request.
@@ -817,7 +852,8 @@ async def test_batch_optimize_tours_async(
     request_type=fleet_routing.BatchOptimizeToursRequest,
 ):
     client = FleetRoutingAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -849,7 +885,9 @@ async def test_batch_optimize_tours_async_from_dict():
 
 
 def test_batch_optimize_tours_field_headers():
-    client = FleetRoutingClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -871,12 +909,17 @@ def test_batch_optimize_tours_field_headers():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 @pytest.mark.asyncio
 async def test_batch_optimize_tours_field_headers_async():
-    client = FleetRoutingAsyncClient(credentials=ga_credentials.AnonymousCredentials(),)
+    client = FleetRoutingAsyncClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
 
     # Any value that is part of the HTTP/1.1 URI should be sent as
     # a field header. Set these to a non-empty value.
@@ -900,7 +943,10 @@ async def test_batch_optimize_tours_field_headers_async():
 
     # Establish that the field header was sent.
     _, _, kw = call.mock_calls[0]
-    assert ("x-goog-request-params", "parent=parent/value",) in kw["metadata"]
+    assert (
+        "x-goog-request-params",
+        "parent=parent/value",
+    ) in kw["metadata"]
 
 
 def test_credentials_transport_error():
@@ -910,7 +956,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = FleetRoutingClient(
-            credentials=ga_credentials.AnonymousCredentials(), transport=transport,
+            credentials=ga_credentials.AnonymousCredentials(),
+            transport=transport,
         )
 
     # It is an error to provide a credentials file and a transport instance.
@@ -930,7 +977,10 @@ def test_credentials_transport_error():
     options = client_options.ClientOptions()
     options.api_key = "api_key"
     with pytest.raises(ValueError):
-        client = FleetRoutingClient(client_options=options, transport=transport,)
+        client = FleetRoutingClient(
+            client_options=options,
+            transport=transport,
+        )
 
     # It is an error to provide an api_key and a credential.
     options = mock.Mock()
@@ -946,7 +996,8 @@ def test_credentials_transport_error():
     )
     with pytest.raises(ValueError):
         client = FleetRoutingClient(
-            client_options={"scopes": ["1", "2"]}, transport=transport,
+            client_options={"scopes": ["1", "2"]},
+            transport=transport,
         )
 
 
@@ -989,10 +1040,28 @@ def test_transport_adc(transport_class):
         adc.assert_called_once()
 
 
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+    ],
+)
+def test_transport_kind(transport_name):
+    transport = FleetRoutingClient.get_transport_class(transport_name)(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert transport.kind == transport_name
+
+
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = FleetRoutingClient(credentials=ga_credentials.AnonymousCredentials(),)
-    assert isinstance(client.transport, transports.FleetRoutingGrpcTransport,)
+    client = FleetRoutingClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+    )
+    assert isinstance(
+        client.transport,
+        transports.FleetRoutingGrpcTransport,
+    )
 
 
 def test_fleet_routing_base_transport_error():
@@ -1032,6 +1101,14 @@ def test_fleet_routing_base_transport():
     with pytest.raises(NotImplementedError):
         transport.operations_client
 
+    # Catch all for all remaining methods and properties
+    remainder = [
+        "kind",
+    ]
+    for r in remainder:
+        with pytest.raises(NotImplementedError):
+            getattr(transport, r)()
+
 
 def test_fleet_routing_base_transport_with_credentials_file():
     # Instantiate the base transport with a credentials file
@@ -1043,7 +1120,8 @@ def test_fleet_routing_base_transport_with_credentials_file():
         Transport.return_value = None
         load_creds.return_value = (ga_credentials.AnonymousCredentials(), None)
         transport = transports.FleetRoutingTransport(
-            credentials_file="credentials.json", quota_project_id="octopus",
+            credentials_file="credentials.json",
+            quota_project_id="octopus",
         )
         load_creds.assert_called_once_with(
             "credentials.json",
@@ -1173,7 +1251,13 @@ def test_fleet_routing_grpc_transport_client_cert_source_for_mtls(transport_clas
             )
 
 
-@pytest.mark.parametrize("transport_name", ["grpc", "grpc_asyncio",])
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
 def test_fleet_routing_host_no_port(transport_name):
     client = FleetRoutingClient(
         credentials=ga_credentials.AnonymousCredentials(),
@@ -1185,7 +1269,13 @@ def test_fleet_routing_host_no_port(transport_name):
     assert client.transport._host == ("cloudoptimization.googleapis.com:443")
 
 
-@pytest.mark.parametrize("transport_name", ["grpc", "grpc_asyncio",])
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "grpc",
+        "grpc_asyncio",
+    ],
+)
 def test_fleet_routing_host_with_port(transport_name):
     client = FleetRoutingClient(
         credentials=ga_credentials.AnonymousCredentials(),
@@ -1202,7 +1292,8 @@ def test_fleet_routing_grpc_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.FleetRoutingGrpcTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1214,7 +1305,8 @@ def test_fleet_routing_grpc_asyncio_transport_channel():
 
     # Check that channel is used if provided.
     transport = transports.FleetRoutingGrpcAsyncIOTransport(
-        host="squid.clam.whelk", channel=channel,
+        host="squid.clam.whelk",
+        channel=channel,
     )
     assert transport.grpc_channel == channel
     assert transport._host == "squid.clam.whelk:443"
@@ -1315,12 +1407,16 @@ def test_fleet_routing_transport_channel_mtls_with_adc(transport_class):
 
 def test_fleet_routing_grpc_lro_client():
     client = FleetRoutingClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1328,12 +1424,16 @@ def test_fleet_routing_grpc_lro_client():
 
 def test_fleet_routing_grpc_lro_async_client():
     client = FleetRoutingAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     transport = client.transport
 
     # Ensure that we have a api-core operations client.
-    assert isinstance(transport.operations_client, operations_v1.OperationsAsyncClient,)
+    assert isinstance(
+        transport.operations_client,
+        operations_v1.OperationsAsyncClient,
+    )
 
     # Ensure that subsequent calls to the property send the exact same object.
     assert transport.operations_client is transport.operations_client
@@ -1361,7 +1461,9 @@ def test_parse_common_billing_account_path():
 
 def test_common_folder_path():
     folder = "whelk"
-    expected = "folders/{folder}".format(folder=folder,)
+    expected = "folders/{folder}".format(
+        folder=folder,
+    )
     actual = FleetRoutingClient.common_folder_path(folder)
     assert expected == actual
 
@@ -1379,7 +1481,9 @@ def test_parse_common_folder_path():
 
 def test_common_organization_path():
     organization = "oyster"
-    expected = "organizations/{organization}".format(organization=organization,)
+    expected = "organizations/{organization}".format(
+        organization=organization,
+    )
     actual = FleetRoutingClient.common_organization_path(organization)
     assert expected == actual
 
@@ -1397,7 +1501,9 @@ def test_parse_common_organization_path():
 
 def test_common_project_path():
     project = "cuttlefish"
-    expected = "projects/{project}".format(project=project,)
+    expected = "projects/{project}".format(
+        project=project,
+    )
     actual = FleetRoutingClient.common_project_path(project)
     assert expected == actual
 
@@ -1417,7 +1523,8 @@ def test_common_location_path():
     project = "winkle"
     location = "nautilus"
     expected = "projects/{project}/locations/{location}".format(
-        project=project, location=location,
+        project=project,
+        location=location,
     )
     actual = FleetRoutingClient.common_location_path(project, location)
     assert expected == actual
@@ -1442,7 +1549,8 @@ def test_client_with_default_client_info():
         transports.FleetRoutingTransport, "_prep_wrapped_messages"
     ) as prep:
         client = FleetRoutingClient(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1451,7 +1559,8 @@ def test_client_with_default_client_info():
     ) as prep:
         transport_class = FleetRoutingClient.get_transport_class()
         transport = transport_class(
-            credentials=ga_credentials.AnonymousCredentials(), client_info=client_info,
+            credentials=ga_credentials.AnonymousCredentials(),
+            client_info=client_info,
         )
         prep.assert_called_once_with(client_info)
 
@@ -1459,7 +1568,8 @@ def test_client_with_default_client_info():
 @pytest.mark.asyncio
 async def test_transport_close_async():
     client = FleetRoutingAsyncClient(
-        credentials=ga_credentials.AnonymousCredentials(), transport="grpc_asyncio",
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="grpc_asyncio",
     )
     with mock.patch.object(
         type(getattr(client.transport, "grpc_channel")), "close"
